from __future__ import unicode_literals

from django.db.models import Model, get_model as django_get_model
from perm.exceptions import PermAppException


def get_model(model):
    print "get_model: %s" % model
    if isinstance(model, basestring):
        app_name, model_name = model.split('.')
        print app_name
        print model_name
        model = django_get_model(app_name, model_name)
    print model
    if not issubclass(model, Model):
        raise PermAppException(_('%(model)s is not a Django Model class.' % {
            'model': model
        }))
    return model



from django.views.generic import DetailView, UpdateView, CreateView

from .http import HttpForbidden


class PermSingleObjectMixin(object):

    perm = None

    def get_object(self, *args, **kwargs):
        obj = super(PermSingleObjectMixin, self).get_object(*args, **kwargs)
        if self.perm and not self.request.user.has_perm(self.perm, obj):
            raise HttpForbidden()
        return obj


class PermDetailView(PermSingleObjectMixin, DetailView):

    perm = 'view'


class PermUpdateView(PermSingleObjectMixin, UpdateView):

    perm = 'change'


class PermCreateView(PermSingleObjectMixin, CreateView):

    perm = 'create'


import re
from setuptools import setup

# Read version from file
VERSION_FILE = 'perm/_version.py'
version_text = open(VERSION_FILE, "rt").read()
VSRE = r"^__version__ = ['\"]([^'\"]*)['\"]"
mo = re.search(VSRE, version_text, re.M)
if mo:
    version = mo.group(1)
else:
    raise RuntimeError("Unable to find version string in %s." % (VERSIONFILE,))

# Setup
setup(
    name='django-perm',
    version=version,
    url='https://github.com/dyve/django-perm',
    author='Dylan Verheul',
    author_email='dylan@dyve.net',
    license='Apache License 2.0',
    packages=['perm', 'perm.templatetags'],
    include_package_data=True,
    description='Class based Django permissions',
    classifiers=[
        "Development Status :: 4 - Beta",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: Apache Software License",
        "Programming Language :: Python",
        "Operating System :: OS Independent",
        "Topic :: Software Development :: Libraries",
        "Topic :: Utilities",
        "Environment :: Web Environment",
        "Framework :: Django",
    ],
)
